.. _api:

Main Interface
--------------

.. autofunction:: translate.translator
.. autofunction:: translate.push_url
.. autofunction:: translate.source
.. autofunction:: translate.spooler
.. autofunction:: translate.text_sink
